@@ -59,14 +59,14 @@ def test_sqa_appbuild_results_record_model_creation(sqa_app_build_result):
 def test_sqa_test_results_record_schema_validation(sqa_test_result):
     model = SqaTestResult(sqa_test_result.dict())
     model.validate_schema()
-    model.testResult = "fail"
+    model.test_result = "fail"
     model.validate_schema()
 
-    model.testCaseId = 4
+    model.test_case_id = 4
     with pytest.raises(SchemaValidationError):
         model.validate_schema()
 
-    model.testResult = "PASS"
+    model.test_result = "PASS"
     with pytest.raises(SchemaValidationError):
         model.validate_schema()
 
