@@ -1,11 +1,8 @@
 import json
-import os
-
 from utf_queue_client.clients.ubai_artifact_upload_request_producer import (
     UbaiArtifactUploadRequestProducer,
 )
 from ubai_client.apis import ArtifactApi
-from urllib import parse
 import click
 from typing import Iterable, Tuple
 from time import sleep
@@ -15,6 +12,8 @@ import requests
 from otel_extensions import instrumented
 from opentelemetry import trace
 
+from utf_queue_client.utils import prepare_queue_central_url
+
 MULTIPART_SIZE_THRESHOLD = 1000000
 
 
@@ -67,17 +66,7 @@ def cli(
     with setup_telemetry():
         url = ""
         if queue:
-            if username is None or password is None:
-                raise RuntimeError(
-                    "username or password must be provided if using queue"
-                )
-            hostname = os.environ.get(
-                "UTF_QUEUE_HOSTNAME", "utf-queue-central.silabs.net"
-            )
-            scheme = os.environ.get("UTF_QUEUE_SCHEME", "amqps")
-            port = os.environ.get("UTF_QUEUE_PORT", "443")
-            virtual_host = os.environ.get("UTF_QUEUE_VIRTUAL_HOST", "%2f")
-            url = f"{scheme}://{username}:{parse.quote(password)}@{hostname}:{port}/{virtual_host}"
+            url = prepare_queue_central_url(username, password)
 
         metadata_dict = {}
         for key, value in metadata:
